@@ -1,4 +1,4 @@
-/* $Id: fmt-latex.h,v 1.8 1997/04/22 20:09:49 dps Exp $ */
+/* $Id: fmt-latex.h,v 1.3 1997/03/31 21:59:42 dps Exp $ */
 /* Shared stuff for the *TeX output format */
 
 #ifndef __fmt_latex_h__
@@ -8,9 +8,7 @@
 #include "latex-table.h"
 
 /* Anything shorter than this is not a real paragraph */
-#define PAR_TRESHOLD_LEN 70
-/* Less than this is not a heading */
-#define HEADING_TRESHOLD_LEN 10
+#define PAR_TRESHOLD_LEN 10
 
 /* Type */
 struct embed
@@ -29,7 +27,7 @@ struct latex_data
     int col;
     int row;
     const char *last_tc;
-    struct unit_info unit_d;
+    int unit_type;
     int par_flg;
     int list_flg;
 };
@@ -43,3 +41,6 @@ extern void ltx_embed(const tok_seq::tok *t, const docfmt *fmt, FILE *out,
 
 #endif  /* __fmt_latex_h__ */
 
+
+
+
