@@ -1,8 +1,6 @@
 /* $Id: tblock.h,v 1.2 1997/03/21 20:20:53 dps Exp $ */
 /* Dynamically grown text block */
 
-#include <string.h>
-
 #ifndef __tblock_h__
 #define __tblock_h__
 
@@ -21,7 +19,7 @@ private:
     struct block *head;
 
     static const struct block dummy_init;
-    static const int block_size=1024;
+    const block_size=1024;
 
     const char *collect(void) const;
 
