@@ -1,49 +1,17 @@
-/* $Id: word2x.cc,v 1.12 1997/04/13 05:53:11 dps Exp $ */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif /* HAVE_CONFIG_H */
-
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else
-#if HAVE_ALLOCA_H
-#include <alloca.h>
-#else /* Do not have alloca.h */
-#ifdef _AIX
-#pragma alloca
-#else /* not _AIX */
-extern "C" char *alloca(int);
-#endif /* _AIX */
-#endif /* HAVE_ALLOCA_H */
-#endif /* __GNUC__ */
-
+/* $Id: word2x.cc,v 1.5 1997/03/31 23:15:38 dps Exp $ */
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif /* HAVE_STRING_H */
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif /* HAVE_STRINGS_H */
-#ifdef HAVE_TIME_H
 #include <time.h>
-#endif /* HAVE_TIME_H */
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#endif /* HAVE_SYS_TIME_H */
-#ifdef HAVE_CTYPE_H
+#include <getopt.h>
 #include <ctype.h>
-#endif /* HAVE_CTYPE_H */
-#include "getopt.h"
 #include "interface.h"
 #include "lib.h"
-#include "strip.h"
 
 #ifndef N
 #define N(x) (sizeof(x)/sizeof(x[0]))
 #endif
 
-extern docfmt txtfmt, latexfmt, htmlfmt;
+extern docfmt txtfmt, latexfmt;
 
 /* postfix test */
 static int postfix(const char *s, const char *t)
@@ -91,7 +59,7 @@ static FILE *open_file(const char *f)
 
 
 /* Just read the files and pass the results on... */
-static void convert(istream *f, FILE *out, const struct docfmt *fmt)
+static void convert(FILE *f, FILE *out, const struct docfmt *fmt)
 {
     const tok_seq::tok *d;
     int i;
@@ -101,11 +69,7 @@ static void convert(istream *f, FILE *out, const struct docfmt *fmt)
     dptr=fmt->new_state();
     while ((d=rd.read_token())!=NULL)
     {
-	i=d->tokval;
-
-#ifndef C_ALLOCA
-	alloca(0);
-#endif
+	i=d->tok;
 
 	if (i<NFUNCS && d->end==tok_seq::tok::TOK_START)
 	{
@@ -125,7 +89,7 @@ static const char *outname(const char *in, const char *ext)
     int adj;
 
     if (postfix(in, ".doc"))
-	adj=4;
+	adj=3;
     else
 	adj=0;
 
@@ -149,9 +113,6 @@ int main(int argc, const char **argv)
 	{ "uk", uk_date },
 	{ "british", uk_date },
 	{ "us", us_date },
-        { "de", de_date },
-        { "deHTML", deHTML_date },
-        { "deL1", deL1_date },
     };
     static const struct
     {
@@ -160,11 +121,9 @@ int main(int argc, const char **argv)
 	const docfmt *fmt;
     } formats[]=
     {
-	{ "text", ".txt", &txtfmt },
-	{ "latex", ".tex", &latexfmt },
-	{ "html", ".html", &htmlfmt },
+	{ "text", "txt", &txtfmt },
+	{ "latex", "tex", &latexfmt },
     };
-#if !defined(NO_LONG_OPTS)
     static const struct option lopts[]=
     {
 	{ "version", 0, NULL, 'V' },
@@ -174,9 +133,7 @@ int main(int argc, const char **argv)
 	{ "dates", 0, NULL, 'd' },
 	{ "verbose", 0, NULL, 'v' },
 	{ "quiet", 0, NULL, 'q' },
-	{ "pagebreak", 0, NULL, 'p' },
     };
-#endif
 
     char *(*dfmt)(time_t);
     FILE *in, *out;
@@ -185,31 +142,23 @@ int main(int argc, const char **argv)
     const char *s,*t, *ext;
     int verbose=0, name_alloced, res;
 
-    struct
-    {
-	unsigned new_pages:1;
-    } flags={ 0 };
     res=0;			// Return code 0
     fmt=*(formats[0].fmt);	// Set default format
     dfmt=dates[0].fmt;		// Set default date format
     wd=fmt.maxline;		// Set default width
     ext=formats[0].ext;		// Set default extension
 
-    while ((c=getopt_long(argc, (char *const *) argv, "Vhpvqf:w:d:",
+    while ((c=getopt_long(argc, (char *const *) argv, "Vhvqf:w:d:",
 			  lopts, &opt_index))!=-1)
     {
 	switch(c)
 	{
 	case 'V':			// Print version and exit
-	    fputs("word2x 0.005\n", stderr);
+	    fputs("word2x 0.001\n", stderr);
 	    return 0;
-
-	case 'p':
-	    flags.new_pages=1;
-	    break;
-
+	    
 	case 'h':			// Help
-	    fputs("Usage: word2x [-f <output format>] [--dates <date format>]"
+	    fputs("Usage: word2x [-f <output format>] [-dates <date format>]"
 		  " [-w <line length>]\n"
 		  "              <infile> [<outfile>]\n"
 		  "Supported date formats: ", stderr);
@@ -319,7 +268,6 @@ int main(int argc, const char **argv)
     /* Set line width and date format */
     fmt.date=dfmt;
     fmt.maxline=wd;
-    fmt.flags.new_pages=flags.new_pages;
 
     /* Loop through files */
     for (i=optind; i<argc; i++)
@@ -353,6 +301,15 @@ int main(int argc, const char **argv)
 	    continue;
 	}
 
+	/* Check seekability of in file */
+	if (fseek(in, 0L, SEEK_SET)!=0)
+	{
+	    fprintf(stderr, "word2x: %s is not seekable\n", s);
+	    fclose(in);
+	    res=1;
+	    continue;
+	}
+
 	/* Open output file */
 	if (strcmp(t,"-")==0)
 	{
@@ -372,16 +329,13 @@ int main(int argc, const char **argv)
 	    }
 	}
 
-	fclose(in);
-	word_junk_filter filt(s);
-	istream in(&filt);
-
 	/* Finally do something */
 	if (verbose)
 	    fprintf(stderr, "Converting %s to %s\n", s, t);
-	convert(&in, out, &fmt);
-
-	/* Junk filter and istream go out of scope here */
+	convert(in, out, &fmt);
+	fclose(in);
+	if (out!=stdout)
+	    fclose(out);
     }
 
     return res;
