@@ -1,21 +1,15 @@
 /* $Id: wordwrap.cc,v 1.5 1997/03/23 13:52:15 dps Exp $ */
 /* Wordwrap function for library */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_CTYPE_H
 #include <ctype.h>
-#endif /* HAVE_CTYPE_H */
 #include "tblock.h"
-#define __EXLCUDE_READER_CLASSES
+#define __EXCLUDE_READER_CLASSES
 #include "lib.h"
 
-
 /* Word wrap text into lines of length room */
 tblock *word_wrap(const char *txt, const char *nl, const char *expl_nl,
-		  const int room, const int ilen)
+		  const int room, const int ilen=0)
 {
     struct tblock *ans;
     const char *wptr, *sc;
